local L = AceLibrary("AceLocale-2.2"):new("YataOptions");
L:RegisterTranslations("enUS", function() 
	return {
	["Button Lock"] = true,
	["Lock the frame"] = true,
	["Button Scale"] = true,
	["Scale the buttons"] = true,
	};
end);
L:RegisterTranslations("deDE", function() 
	return {
	["Button Lock"] = "Knpfe sperren",
	["Lock the frame"] = "Fenster sperren",
	["Button Scale"] = "Knopf Skalierung",
	["Scale the buttons"] = "Knpfe skalieren",
	};
end);


---------------------
-- Options Support --
---------------------


function Yata:InitOptions()
	local options = {
		type="group",
		args = {
			addonheader = {
				name = "Yata",
				type = "header",
				order = 1,
			},
			lock = {
				name = L["Lock the frame"],
				desc = L["Lock the frame"],
				type = "toggle",
				get = function() return self.db.profile.Locked end,
				set = function(v)
					self.db.profile.Locked = v;
					if(self.IsInitialized) then
						self.TotemBar:SaveConfig();
					end
				end,
				disabled = function() return InCombatLockdown() end,
			},
			buttonlock = {
				name = L["Button Lock"],
				type = "toggle",
				desc = L["Button Lock"],
				get = function() return self.db.profile.ButtonLocked end,
				set = function(v)
					self.db.profile.ButtonLocked = v;
					if(self.IsInitialized) then
						self.TotemBar:SetupSwap(v);
					end
				end,
				disabled = function() return InCombatLockdown() end,
			},
			scale = {
				name = L["Button Scale"],
				desc = L["Scale the buttons"],
				type = "range",
				get = function() return self.db.profile.ButtonScale end,
				set = function(v)
					self.db.profile.ButtonScale = v;
					if(self.IsInitialized) then
						self.TotemBar:SaveConfig();
					end
				end,
				min = 0.5,
				max = 1.5,
				step = 0.05,
				disabled = function() return InCombatLockdown() end,
			},
			invertbar = {
				name = "Invert bar direction",
				desc = "Invert bar direction",
				type = "toggle",
				get = function() return self.db.profile.InvertBar end,
				set = function(v)
					self.db.profile.InvertBar = v;
					if(self.IsInitialized) then
						self:Print("You'll need to /console reloadui now");
						self.TotemBar:SaveConfig();
					end
				end,
				disabled = function() return InCombatLockdown() end,
				},
			tooltips = {
				name = "Tooltips",
				desc = "Tooltip configuration",
				type = "group",
				args = {
					showtooltip = {
						name = "Show Tooltip",
						type = "toggle",
						desc = "Show Tooltip",
						get = function() return self.db.profile.ShowTooltip end,
						set = function(v)
							self.db.profile.ShowTooltip = v;
							self.db.profile.ShowTTOOC = v;
							if(self.IsInitialized) then
								self.TotemBar:SaveConfig();
							end
						end,
					},
					showooconly = {
						name = "Out of combat only",
						type = "toggle",
						desc = "Show Tooltip out of combat only",
						get = function() return self.db.profile.ShowTTOOC end,
						set = function(v)
							self.db.profile.ShowTTOOC = v;
							if(self.IsInitialized) then
								self.TotemBar:SaveConfig();
							end
						end,
					},			
				},
				disabled = function() return InCombatLockdown() end,
			},
			totemsets = {
				name = "Totemsets",
				desc = "Totemsets",
				type = "group",
				args = {
					header = { 
						type = "header",
						name = "No active Set",
						order = 1,
					},
					addset = {
						name = "Add",
						desc = "Add",
						type = "execute",
						func = function()
							self.TotemBar.EditSet = true; 
							self.TotemBar.TempTotemSet = {};
							self.TotemBar:SetupSwap(nil);
							self.TotemBar:SaveConfig();
							self.db.profile.ButtonLocked = false;
							StaticPopup_Show("YataAddSet");
						end,
					},
					loadset = {
						name = "Load",
						desc = "Load Set",
						type = "group",
						args = {},
						disabled = function() return next(Yata.options.args.totemsets.args.loadset.args) == nil end
					},
					deleteset = {
						name = "Delete",
						desc = "Delete Set",
						type = "group",
						args = {},
						disabled = function() return next(Yata.options.args.totemsets.args.deleteset.args) == nil end
					},
					reset = {
						name = "Switch to default layout",
						desc = "Switch to default layout",
						type = "execute",
						func = function() self.TotemBar:ResetSet(); end,
					},
				},
				disabled = function() return InCombatLockdown() end,
			},
			keybindings = {
				name = "Keybindings",
				desc = "Keybindings",
				type = "group",
				args = {},
				disabled = function() return InCombatLockdown() end,
			},
		}
	};
self:InitDialogs();
return options;
end

-- Originally found in Closetgnome by Rabbitw
function Yata:InitDialogs()
	if not StaticPopupDialogs then
		StaticPopupDialogs = {}
	end
	StaticPopupDialogs["YataAddSet"] = {
		text = "Please enter the name for your Set, it the name is already existing the two Sets will be merged, any changes to the button layout will be now done on this set. Swapping the same button several times is buggy",
		button1 = "Add",
		button2 = "Cancel",
		OnCancel = function() self.TotemBar.EditSet = false; self.TotemBar:SetupSwap(true); self.db.profile.ButtonLocked = true; end,
		sound = "levelup2",
		whileDead = 1,
		hideOnEscape = 1,
		timeout = 0,
		OnShow = function()
			-- We have to do this onshow to reset the previous text
			_G[this:GetName().."EditBox"]:SetText("")
		end,
		OnAccept = function()
			local name = _G[this:GetParent():GetName().."EditBox"]:GetText()
			self.TotemBar:AddTotemSet(name);
			self.TotemBar:SetupSwap(true);
			self.db.profile.ButtonLocked = true;
			self.TotemBar.EditSet = false;
		end,
		hasEditBox = 1,
	}
	StaticPopupDialogs["YataDeleteSet"] = {
		text = "Are you sure you want to delete the set %s?",
		button1 = "Delete",
		button2 = "Cancel",
		showAlert = 1,
		timeout = 0,
		OnAccept = function() self.TotemBar:DeleteTotemSet(); end,
		OnCancel = function() end,
	}

end