local deformat = AceLibrary("Deformat-2.0");
local YataTT = AceLibrary("Gratuity-2.0");
local L = AceLibrary("AceLocale-2.2"):new("YataTotemData");
L:RegisterTranslations("enUS", function() 
	return {
	["Air"] = true,
	["Water"] = true,
	["Earth"] = true,
	["Fire"] = true,
	["Totem"] = true,
	["totem"] = "Totem",
	["Tools"] = true,
	["health"] = true,
	["points"] = true,
	["min"] = true,
	["sec"] = true,
	["Totemic Call"] = true,
	};
end);
L:RegisterTranslations("deDE", function() 
	return {
	["Air"] = "Luft",
	["Water"] = "Wasser",
	["Earth"] = "Erde",
	["Fire"] = "Feuer",
	["Totem"] = "Totem",
	["totem"] = "totem",
	["Tools"] = "Werkzeuge",
	["health"] = "Gesundheit",
	["points"] = "Punkt%(en%)",
	["min"] = "Min.",
	["sec"] = "Sek.",
	["Totemic Call"] = "Ruf des Totems";
	};
end);
local Yata_TotemTiming = {L["min"], L["sec"]};
-- potential Blacklist to get around spells with the Totemstring and which aren't Totems at all
local Yata_SpellBlacklist = {L["Totemic Call"]};



----------
-- Init --
----------

function Yata:TotemsInit()
	self.ElementsCount = {["Earth"] = 0, ["Air"] = 0, ["Water"] = 0, ["Fire"] = 0};
	if(not self.db.profile.TotemsOrder) then
		self.db.profile.TotemsOrder = {"Earth","Air","Water","Fire"};
		for i=1,4 do
			self.db.profile.TotemsOrder[self.db.profile.TotemsOrder[i]] = {};
		end
	end
	self:GatherTotemData();
	self:CleanTotemProfile();
end
---------------------------
-- Get Position by totem --
---------------------------

function Yata:GetPosByTotem(totem)
	local retval = 0;
	if(self.db.profile.TotemsOrder[totem.Element]) then
		for k,v in pairs(self.db.profile.TotemsOrder[totem.Element]) do
			if(v == totem.Name) then retval = k;
				break;
			end
		end
	end
	return retval;
end

-----------------------------
-- Return order by element --
-----------------------------

function Yata:ReturnOrderByElement(ele)
	local retval = 0;
	for i=1,4 do
		if(self.db.profile.TotemsOrder[i] == ele) then
			retval = i;
			break;
		end
	end
	return retval;
end

-----------------------
-- CleanTotemProfile --
-----------------------

function Yata:CleanTotemProfile()
	if(self.TotemData.Count ~= self.db.profile.TotemsCount) then
		self:Print("Totem count mismatch: removing not existing ones...");
		local newtotems = {};
		for i=1,4 do
			local counter = 1;
			newtotems[i] = self.db.profile.TotemsOrder[i];
			newtotems[newtotems[i]] = {};
			for k,v in ipairs(self.db.profile.TotemsOrder[self.db.profile.TotemsOrder[i]]) do
				local found = nil;
				for l,w in pairs(self.TotemData) do
					if(v == w) then
						(newtotems[newtotems[i]])[counter] = v;
						counter = counter + 1;
						found = true;
						break;
					end
				end
				if(not found) then 
					self:Print("Couldn't find: "..v..", removing it");
				end
			end
		end
		self.db.profile.TotemsOrder = newtotems;
	end
end


-----------------------------
-- Utility functions below --
-----------------------------
function Yata:SpellBlacklist(spell)
	local blacklist = nil;
	for k,v in pairs(Yata_SpellBlacklist) do
		if(spell == v) then
			blacklist = true;
			break;
		end
	end
	return blacklist
end

function Yata:GatherTotemData()
    self.TotemData = {};
    local tabs = GetNumSpellTabs();
    for tab = 2, tabs do
	local _, _, offset, numSpells = GetSpellTabInfo(tab);
	for i = 1, numSpells do
	    local spell = offset + i;
	    local SpellName, subspell = GetSpellName(spell, "spell");
	    if (string.find(string.lower(SpellName), string.lower(L["Totem"])) and not self:SpellBlacklist(SpellName)) then
		if (not self.TotemData[SpellName]) then
		    self.TotemData[SpellName] = {};
		    table.insert(self.TotemData, SpellName);
		end
		local data = {};
		data.SpellID = spell;
		table.insert(self.TotemData[SpellName],data);
	    end
	end
    end
    local count = 0;
    -- Add Spell Information (Cooldown,Duration, HP, Element)
    	for k,v in ipairs(self.TotemData) do
    		for l,w in ipairs(self.TotemData[v]) do
			local data = self:ExtractToolTip(w.SpellID);
			w.Element = data.element;
			w.Cooldown = data.Cooldown;
			w.Health = data.health;
			w.Duration = data.duration;
			w.Mana = data.mana;
			w.Name = v;
			w.Texture = GetSpellTexture(w.SpellID,"spell");
		end
		count = count + 1;
	end
    self.TotemData.Count = count;
end
--- Return Cooldown, Duration, HP, Element
--- Not yet fully converted to Gratuity/Deformat
function Yata:ExtractToolTip(spellid)
	local element = "";
	local data = {};
	data.element = "";
	data.Cooldown = 0;
	data.health = 0;
	data.duration = 0;
	data.mana = 0;
	YataTT:SetSpell( spellid, "spell" );
	-- Mana cost --
	data.mana = YataTT:FindDeformat(MANA_COST,2,2,false,true);
	-- Element extraction --
	local elesearch = L["Tools"]..": (.*)"..L["totem"];
	local _,_, element = YataTT:Find(elesearch,4,4,false,true);
	if( element ) then	
		if( string.sub( element, 1, 1 ) == "|" ) then
			element = string.sub( element, 11 );
		end
		_, _, element = string.find(element, "(%a*)");
		-- localization hacks incoming --
		if( GetLocale() == "deDE" ) then
			if(element == "Erd") then
				element = "Erde"; -- "Werkzeuge: Erdtotem", rename Erd to Erde
			end
		end
		data.element = L:GetReverseTranslation(element);
		if(not data.element) then
			self:Debug("Localization bug incoming");
		end
	end
	-- End Element --
	text = YataTT:GetLine(5,nil);
	-- Start HP --
	local _, _, health = YataTT:Find("(%d+) "..L["health"],5,5,false,true);
	if(not health) then
		_, _, health = YataTT:Find("(%d+) "..L["points"].." "..L["health"],5,5,false,true);
	end
	data.health = health;
	-- End HP --
	-- Start Duration --     
	     local matches = {};
	     for num, regex in ipairs(Yata_TotemTiming) do
		     for k in string.gmatch(text,"(%d+) "..regex) do
	       		if(num == 1) then
	       			table.insert(matches,tonumber(k*60));
	       		else 	table.insert(matches,tonumber(k));
	       		end
		     end
	     end
	     table.sort(matches);
	     data.duration = matches[table.getn(matches)];
	-- End Duration --
	-- Start Cooldown -- 
	local matches = {};
	text = YataTT:GetLine(3,true);
	if(text) then
	     for num, regex in ipairs(Yata_TotemTiming) do
		     for k in string.gmatch(text,"(%d+) "..regex) do
	       		if(num == 1) then
	       			table.insert(matches,tonumber(k*60));
	       		else 	table.insert(matches,tonumber(k));
	       		end
		     end
	     end
	     table.sort(matches);
	     data.Cooldown = matches[table.getn(matches)];
	end
	-- End Cooldown --
	return data;
end
function Yata:OutputTotemData()
	for k,v in ipairs(self.TotemData) do
		for l,w in ipairs(self.TotemData[v]) do
			self:Print(v.." ".."(Rank "..l.."), HP: "..w.Health..", Duration: "..w.Duration..", Element: "..w.Element..", Cooldown: "..w.Cooldown..", Mana: "..w.Mana);
		end
	end
end